Protocol class

Constructors

Protocol(String name, {PacketFactory? packetFactory, int? ipProtocolNumber})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipProtocolNumber → int?
final
name → String
final
packetFactory → PacketFactory?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited