Ip4Packet class

Inheritance

Constructors

Ip4Packet()

Properties

destination ↔ Ip4Address?
Destination IP address.
getter/setter pairinherited
flags ↔ int
3-bit flags.
getter/setter pair
fragmentOffset ↔ int
13-bit fragment offset.
getter/setter pair
hashCode → int
Computes a hash code based on the serialized bytes.
no setterinherited
identification ↔ int
16-bit identification
getter/setter pair
ipVersion → int
IP version (4 or 6)
no setteroverride
options ↔ SelfEncoder
IPv4 options. Maximum length is 40 bytes.
getter/setter pair
payload ↔ SelfEncoder
getter/setter pairinherited-getteroverride-setter
payloadProtocolNumber ↔ int
8-bit encapsulated protocol (e.g. TCP, UDP).
getter/setter pairoverride-getter
protocol → Protocol
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ Ip4Address?
Source IP address.
getter/setter pairinherited
ttl ↔ int
8-bit time-to-live.
getter/setter pair
typeOfService ↔ int
8-bit type of service.
getter/setter pair

Methods

decodeSelf(RawReader reader) → void
Decodes the current object from the given RawReader.
decodeSelfFromSelfEncoder(SelfEncoder value) → void
Decodes this object from a SelfEncoder by first serializing it to immutable bytes and then reading them via RawReader.
inherited
encodeSelf(RawWriter writer) → void
Writes this object to the provided RawWriter.
encodeSelfCapacity() → int
Returns an estimated maximum number of bytes required for encoding.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toImmutableByteData() → ByteData
Serializes this object to an immutable ByteData.
inherited
toImmutableBytes() → List<int>
Serializes this object to an immutable list of bytes.
inherited
toMutableByteData() → ByteData
Serializes this object to a mutable ByteData buffer.
inherited
toMutableBytes() → List<int>
Serializes this object to a mutable list of bytes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
Compares this object with another SelfEncoder by serialized content.
inherited

Static Methods

calculateChecksum(ByteData byteData, int index, int length, {int checksum = 0}) → int