Ip6Address class

Inheritance

Constructors

Ip6Address.decode(RawReader reader)
factory
Ip6Address.fromBytes(List<int> bytes)
factory

Properties

hashCode → int
Computes a hash code based on the serialized bytes.
no setterinherited
isIpv4 → bool
Inspects whether the address is IPv4 address or IPv6 mapping of IPv4 address.
no setteroverride
isLocalNetwork → bool
Inspects whether the address is a local network address (e.g. 10.0.01).
no setteroverride
isLoopback → bool
Inspects whether the address is loopback address (e.g. 127.0.0.1)
no setteroverride
protocol → Protocol
Returns protocol (ipv4 or ipv6).
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
v0 → int
final
v1 → int
final
v2 → int
final
v3 → int
final

Methods

encodeSelf(RawWriter writer) → void
Writes this object to the provided RawWriter.
encodeSelfCapacity() → int
Returns an estimated maximum number of bytes required for encoding.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toImmutableByteData() → ByteData
Serializes this object to an immutable ByteData.
inherited
toImmutableBytes() → List<int>
Serializes this object to an immutable list of bytes.
inherited
toMutableByteData() → ByteData
Serializes this object to a mutable ByteData buffer.
inherited
toMutableBytes() → List<int>
Serializes this object to a mutable list of bytes.
inherited
toString() → String
Returns string representation of the address.
override

Operators

operator ==(Object other) → bool
Compares this object with another SelfEncoder by serialized content.
inherited

Static Properties

any → Ip6Address
final
broadcast → Ip6Address
final
loopback → Ip6Address
final
zero → Ip6Address
final

Static Methods

parse(String source) → Ip6Address
Parses either Ip4Address or Ip6Address.
override