Ip6Packet class

Inheritance

Constructors

Ip6Packet()

Properties

destination ↔ Ip6Address?
Destination IP address.
getter/setter pairinherited
flowLabel ↔ int
20-bit flow label
getter/setter pair
hashCode → int
Computes a hash code based on the serialized bytes.
no setterinherited
hopLimit ↔ int
8-bit hop limit
getter/setter pair
ipVersion → int
IP version (4 or 6)
no setteroverride
payload ↔ SelfEncoder
getter/setter pairinherited-getteroverride-setter
payloadProtocolNumber ↔ int
8-bit encapsulated protocol (e.g. TCP, UDP).
getter/setter pairoverride-getter
protocol → Protocol
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ Ip6Address?
Source IP address.
getter/setter pairinherited
trafficClass ↔ int
8-bit traffic class
getter/setter pair

Methods

decodeSelf(RawReader reader) → void
Decodes the current object from the given RawReader.
decodeSelfFromSelfEncoder(SelfEncoder value) → void
Decodes this object from a SelfEncoder by first serializing it to immutable bytes and then reading them via RawReader.
inherited
encodeSelf(RawWriter writer) → void
Writes this object to the provided RawWriter.
encodeSelfCapacity() → int
Returns an estimated maximum number of bytes required for encoding.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toImmutableByteData() → ByteData
Serializes this object to an immutable ByteData.
inherited
toImmutableBytes() → List<int>
Serializes this object to an immutable list of bytes.
inherited
toMutableByteData() → ByteData
Serializes this object to a mutable ByteData buffer.
inherited
toMutableBytes() → List<int>
Serializes this object to a mutable list of bytes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
Compares this object with another SelfEncoder by serialized content.
inherited