IpAddress class abstract

Superclass of Ip4Address and Ip6Address.

Implementers

Constructors

IpAddress()
const

Properties

hashCode → int
Computes a hash code based on the serialized bytes.
no setterinherited
isIpv4 → bool
Inspects whether the address is IPv4 address or IPv6 mapping of IPv4 address.
no setter
isLocalNetwork → bool
Inspects whether the address is a local network address (e.g. 10.0.01).
no setter
isLoopback → bool
Inspects whether the address is loopback address (e.g. 127.0.0.1)
no setter
protocol → Protocol
Returns protocol (ipv4 or ipv6).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encodeSelf(RawWriter writer) → void
Writes this object to the provided RawWriter.
inherited
encodeSelfCapacity() → int
Returns an estimated maximum number of bytes required for encoding.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toImmutableByteData() → ByteData
Serializes this object to an immutable ByteData.
inherited
toImmutableBytes() → List<int>
Serializes this object to an immutable list of bytes.
inherited
toMutableByteData() → ByteData
Serializes this object to a mutable ByteData buffer.
inherited
toMutableBytes() → List<int>
Serializes this object to a mutable list of bytes.
inherited
toString() → String
Returns string representation of the address.
override

Operators

operator ==(Object other) → bool
Compares this object with another SelfEncoder by serialized content.
inherited

Static Methods

fromBytes(List<int> bytes) → IpAddress
parse(String source) → IpAddress
Parses either Ip4Address or Ip6Address.